@@ -36,10 +36,29 @@ async def exec():
 
     print('Django project created')
 
-    print('Creating files...')
-
     venv_path = project_path / 'venv'
 
+    bin_path = venv_path / 'bin'
+
+    pip_path = bin_path / 'pip'
+
+    requirements_path = project_path / 'requirements.txt'
+
+    args.packages.extend(const.REQUIRED_PACKAGES)
+
+    print(f'Creating virtual environment at {venv_path}')
+    if args.python:
+        await run_cmd([
+            args.python,
+            '-m',
+            'venv',
+            str(venv_path)
+        ])
+    else:
+        venv.create(str(venv_path), with_pip=True)
+
+    print(f'Created virtual environment at {venv_path}')
+
     tasks = [
         write_file(
             str(project_path / '.gitignore'),
@@ -54,51 +73,23 @@ async def exec():
             const.ENV_EXAMPLE
         ),
         utils.write_settings(str(project_path / args.name / 'settings.py')),
-    ]
-
-    if args.python:
-        tasks.append(
-            run_cmd([
-                args.python,
-                '-m',
-                'venv',
-                str(venv_path)
-            ])
+        utils.install_packages(
+            str(pip_path),
+            args.packages,
+            str(requirements_path),
+            *(('--no-compile',) if args.no_compile else tuple())
         )
-    else:
-        print(f'Creating virtual environment at {venv_path}')
-
-        venv.create(str(venv_path), with_pip=True)
-
-        print(f'Created virtual environment at {venv_path}')
+    ]
 
     if args.git:
         tasks.append(repo.init())
 
+    print('Creating files...')
+
     await asyncio.gather(*tasks)
 
     print('Created files')
 
-    bin_path = venv_path / 'bin'
-
-    pip_path = bin_path / 'pip'
-
-    print('Installing required packages...')
-
-    args.packages.extend(const.REQUIRED_PACKAGES)
-
-    await utils.install_packages(
-        str(pip_path),
-        args.packages,
-        *(('--no-compile',) if args.no_compile else tuple())
-    )
-
-    print('Installed required packages')
-
-    requirements_path = project_path / 'requirements.txt'
-
-    await utils.write_requirements(str(requirements_path), str(pip_path))
-
     tasks = []
 
     if args.git and args.commit:
