@@ -1,5 +1,3 @@
-from typing import List
-
 GITIGNORE: str = '/venv\n/static\n/media\n__pycache__\n*.sqlite*\n*.log\n.env'
 
 ENV_EXAMPLE: str = '''
@@ -12,7 +10,7 @@ ALLOWED_HOSTS=
 DEBUG=
 '''
 
-REQUIRED_PACKAGES: List[str] = (
+REQUIRED_PACKAGES: list[str] = (
     'wheel',
     'django',
     'django-environ',
